#include <iostream>
#include <string>
#include <vector>
#include <random>

using namespace std;

constexpr int SEED = 123;
constexpr int ROUNDS = 1'000'000;
constexpr int WINDOW = 5000;

int main() {
    ios::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);

    mt19937 rng(SEED);

    int n;
    string s;

    cin >> n >> s;

    vector<int> prefix_sums(2 * n, 0);
    for (int i = 0; i < 2 * n - 1; ++i) {
        prefix_sums[i + 1] = prefix_sums[i] + int(s[i] == 'W');
    }

    vector<int> freq(2 * n, 0);
    for (int i = 0; i < ROUNDS; ++i) {
        int l = n + rng() % n;
        int a = rng() % (2 * n - l);
        int b = a + l - 1;
        ++freq[prefix_sums[b + 1] - prefix_sums[a]];
    }

    int k = 0;
    int sum = 0;
    int r;
    for (r = 0; r < min(WINDOW, 2 * n - 1); ++r) sum += freq[r + 1];
    int max_sum = sum;
    for ( ; r < 2 * n - 1; ++r) {
        sum += freq[r + 1] - freq[r - WINDOW + 1];
        if (sum > max_sum) {
            k = r - WINDOW + 1;
            max_sum = sum;
        }
    }

    int cnt;

    auto attempt = [&](int const& h) {
        cnt = 0;
        int l = 0, r;
        for (r = 0; r < 2 * n - 1 && prefix_sums[r + 1] < h; ++r);
        while (cnt < n && r < 2 * n - 1) {
            while (prefix_sums[r + 1] - prefix_sums[l] > h) ++l;
            for (
                    int i = l;
                    cnt < n
                        && r - i + 1 >= n
                        && prefix_sums[r + 1] - prefix_sums[i] == h;
                    ++i
                ) {
                ++cnt;
            }
            ++r;
        }
        return cnt == n;
    };

    for (int d = 0; k - d >= 0 || k + d <= 2 * n - 1; ++d) {
        if (k - d >= 0 && attempt(k - d)) {
            cout << k - d << endl;
            break;
        }
        if (d != 0 && k + d <= 2 * n - 1 && attempt(k + d)) {
            cout << k + d << endl;
            break;
        }
    }

    return 0;
}
